/**
  * @file
  *
  * @author Nadi Sarrar <nadi@net.t-labs.tu-berlin.de>
  *
  * @section LICENSE
  *
  * libTFO, a flow offloading decision engine designed for switch controllers.
  *
  * Copyright (C) 2010, 2011  Nadi Sarrar <nadi@net.t-labs.tu-berlin.de>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  * @section DESCRIPTION
  *
  * Some helper functions to ease the implementation of network controllers
  * that decide to use libTFO.
  */

#ifndef __EXTRAS_HH__
#define __EXTRAS_HH__

#include <libtfo/tfo.hh>

using namespace std;

/**
  * Converts a FibEntryState into an informative string.
  *
  * @param[in] s State to be translated into a string.
  */
const string fib_entry_state_str (const enum FibEntryState s);

/**
  * Converts a FibEntryTable into an informative string.
  *
  * @param[in] t Table to be translated into a string.
  */
const string fib_entry_table_str (const enum FibEntryTable t);

/**
  * Converts a FibEntryUpdateType into an informative string.
  *
  * @param[in] t Update type to be translated into a string.
  */
const string fib_entry_update_type_str (const enum FibEntryUpdateType t);

#endif
