/**
  * @file
  *
  * @author Nadi Sarrar <nadi@net.t-labs.tu-berlin.de>
  *
  * @section LICENSE
  *
  * libTFO, a flow offloading decision engine designed for switch controllers.
  *
  * Copyright (C) 2010, 2011  Nadi Sarrar <nadi@net.t-labs.tu-berlin.de>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  * @section DESCRIPTION
  *
  * Some helper functions for switch controllers that make use of libTFO.
  */

#include <libtfo/extras.hh>

const string fib_entry_state_str (const enum FibEntryState s)
{
	switch (s)
	{
	case FIB_ENTRY_STATE_INACTIVE:
		return "INACTIVE";
	case FIB_ENTRY_STATE_ACTIVE:
		return "ACTIVE";
	case FIB_ENTRY_STATE_MOD_ADD:
		return "MOD_ADD";
	case FIB_ENTRY_STATE_MOD_MOVE:
		return "MOD_MOVE";
	case FIB_ENTRY_STATE_MOD_ACTION:
		return "MOD_ACTION";
	case FIB_ENTRY_STATE_MOD_REMOVE:
		return "MOD_REMOVE";
	}
	return "?";
}

const string fib_entry_table_str (const enum FibEntryTable t)
{
	switch (t)
	{
	case FIB_ENTRY_TABLE_FAST:
		return "FAST";
	case FIB_ENTRY_TABLE_SLOW:
		return "SLOW";
	}
	return "?";
}

const string fib_entry_update_type_str (const enum FibEntryUpdateType t)
{
	switch (t)
	{
	case FIB_ENTRY_ADD:
		return "ADD";
	case FIB_ENTRY_REMOVE:
		return "REMOVE";
	case FIB_ENTRY_MODIFY:
		return "MODIFY";
	}
	return "?";
}
